==> haskell-pipes-http-1.0.5-141-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-259Rxi41s9SFEv9q1MHUtE
key: pipes-http-1.0.5-259Rxi41s9SFEv9q1MHUtE
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
abi: b3fffe18a44dcd42bc2d8065f941cfc3
exposed: True
exposed-modules:
    Pipes.HTTP
import-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-259Rxi41s9SFEv9q1MHUtE
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    pipes-4.3.9-5LDiOgGQhHM8dFV0g0OdEh
    http-client-0.5.13-3Kl4d46bfFOKlGDkbjwGGp
    http-client-tls-0.3.5.3-914vPpmkuItIyNRE5gRsD8
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             pipes-4.3.9-5LDiOgGQhHM8dFV0g0OdEh=d30ef598e9afebff80b7fc08d02c1176
             http-client-0.5.13-3Kl4d46bfFOKlGDkbjwGGp=08ed2990fe4124043525924df120813a
             http-client-tls-0.3.5.3-914vPpmkuItIyNRE5gRsD8=783174f06afa209b1c7224a9e2ce9159
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.5-153-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-COj75NACv8hBLLunP95LLt
key: pipes-http-1.0.5-COj75NACv8hBLLunP95LLt
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
abi: 7d0bb194a7565869714899ac78d94c5a
exposed: True
exposed-modules:
    Pipes.HTTP
import-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-COj75NACv8hBLLunP95LLt
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    pipes-4.3.9-5LDiOgGQhHM8dFV0g0OdEh
    http-client-0.5.13.1-5ctzeCsWHcPJ877FU28ph4
    http-client-tls-0.3.5.3-5td3xvfNmvv2T34HsxLZV4
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             pipes-4.3.9-5LDiOgGQhHM8dFV0g0OdEh=d30ef598e9afebff80b7fc08d02c1176
             http-client-0.5.13.1-5ctzeCsWHcPJ877FU28ph4=ee0b85183d052f0418e0355e32900cbe
             http-client-tls-0.3.5.3-5td3xvfNmvv2T34HsxLZV4=1a850216d6ee113f7db37aceb7b7a431
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
